#!/bin/csh

set program_name=`basename $0`
echo "$program_name started at `date`"

set sun_elevation=`passinfo pass_number=$LASTPASS item=sunelev`

if ( $sun_elevation > 0 ) then
   set day=yes
   set channels="1 2 3 4 5"
   set nav_var="avhrr_ch2"
else
   set day=no
   set channels="3 4 5"
   set nav_var="avhrr_ch5"
endif

hrptin \
   hrpt_types= \
   on_pass_disk=yes \
   pass_number=$LASTPASS \
   channels="$channels" \
   fix_missing= \
   sharpen= \
   calibrate= \
   temp_units= \
   byte_output= \
   full_report= \
   solar_corr= \
   geo_correct= \
   delta_line= \
   delta_sample= \
   use_master=no \
   start_time= \
   num_lines= \
   start_sample= \
   num_samples= \
   level1

navbox2 \
   variable="$nav_var" \
   coast_file= \
   box_height= \
   box_width= \
   min_cross_dev= \
   min_feature= \
   max_regions= \
   min_region_perc= \
   min_coast_pts= \
   min_sat_elev= \
   min_good_boxes= \
   level1.avhrr boxfile

nav2 \
   expr_vars="$nav_var" \
   expression=x1 \
   box_file=boxfile \
   coast_file= \
   max_line_shift= \
   max_samp_shift= \
   min_good_boxes= \
   fix_attitude= \
   reset_sat= \
   method= \
   min_corr= \
   interp_corr= \
   min_feature= \
   fixed_thresh= \
   stdev_units= \
   num_bins= \
   estimate_range= \
   level1.avhrr

nitpix \
   sst_method= \
   cos_sat_zen= \
   ch4_delta= \
   ch2_max= \
   ch2_delta= \
   ch3_minus_ch4= \
   base_temp= \
   temp_step= \
   min_ch4_temp= \
   min_sun_reflect= \
   level1.avhrr level2.sst

if ( "$day" == "yes" ) then
   emathp \
   expr_vars="avhrr_ch1 avhrr_ch2" \
   num_exprs=4 \
   y1_expr="x2 - x1" \
   y2_expr="x2 + x1" \
   y3_expr="y1 / y2" \
   y4_expr="land ? y3 : badval" \
   use_degrees= \
   poly_size= \
   save_exprs=4 \
   var_names=ndvi \
   var_units= \
   var_types=float \
   level1.avhrr level2.ndvi

   copyvar \
   include_vars= \
   overwrite_vars= \
   level2.sst level2.ndvi \

   mv level2.ndvi level2.all

else
   mv level2.sst level2.all
endif

copyvar \
   include_vars= \
   overwrite_vars= \
   level1.avhrr level2.all

setname template=yyyymmdd.hhmm.cnn level2.all

echo "$program_name finished at `date`"

exit 0

