#!/bin/csh -f
#
# Section Four NDVI script
# Make sure input file exists and contains correct variables

set FUNC = avhrr_ndvi

# Check command line arguments

if ($#argv != 1) then
  echo Usage: ${FUNC} input-file
  exit 1
endif

# Derive output file name from input file name

set INPFILE = $1
set OUTFILE = ${INPFILE:r}.ndvi

# Make sure input file exists

if (! -f $INPFILE) then
  echo ${FUNC}: Input file $INPFILE does not exist
  exit 1
endif

# Check for specific variables in input file

set VARLIST = `varnames include_vars="avhrr_ch1 avhrr_ch2" $INPFILE`
if ($status != 0) exit 1

if ($#VARLIST != 2) then
  echo: ${FUNC}: $INPFILE does not contain both avhrr_ch1 and avhrr_ch2
  exit 1
endif

# Run emath using input file from command line

emathp                                       \
  expr_vars="avhrr_ch1 avhrr_ch2"            \
  num_exprs=1                                \
  y1_expr='land ? (x2-x1)/(x2+x1) : badval'  \
  use_degrees=                               \
  poly_size=                                 \
  var_names=ndvi                             \
  var_units=ndvi                             \
  var_types=short                            \
  scale_offsets=0                            \
  scale_factors=100                          \
$INPFILE $OUTFILE

exit $status

