#!/bin/csh -f
#
# Section Six NDVI script
# Add an optional command line parameter for minimum daytime sun elevation

set FUNC = avhrr_ndvi

# Setup TeraScan style command line argument processing

source $TSCANROOT/bin/tsargs

# Check command line arguments

set FILES   = `getfiles`
set DAYELEV = `getparam -p min_sun_elev -d 10`

if ($#FILES != 1) then
  echo "Usage: ${FUNC} [min_sun_elev=#degrees] input-file"
  exit 1
endif

# Derive output file name from input file name

set INPFILE = $FILES
set OUTFILE = ${INPFILE:r}.ndvi

# Make sure input file exists

if (! -f $INPFILE) then
  echo ${FUNC}: Input file $INPFILE does not exist
  exit 1
endif

# Check for specific variables in input file

set VARLIST = `varnames include_vars="avhrr_ch1 avhrr_ch2" $INPFILE`
if ($status != 0) exit 1

if ($#VARLIST != 2) then
  echo: ${FUNC}: $INPFILE does not contain both avhrr_ch1 and avhrr_ch2
  exit 1
endif

# Make sure the sun elevation is greater than DAYELEV degrees

set SUNELEV = `etxinfo item=center_sun $INPFILE`
if ($status != 0) exit 1

if ($SUNELEV == unknown) then
  echo ${FUNC}: Cannot compute sun elevation for $INPFILE
  exit 1
endif

if ($SUNELEV < $DAYELEV) then
  echo ${FUNC}: $INPFILE center sun elevation is $SUNELEV degrees
  echo ${FUNC}: Day time minimum sun elevation is $DAYELEV degrees
  exit 3
endif

# Run emath using input file from command line

emathp                                       \
  expr_vars="avhrr_ch1 avhrr_ch2"            \
  num_exprs=1                                \
  y1_expr='land ? (x2-x1)/(x2+x1) : badval'  \
  use_degrees=                               \
  poly_size=                                 \
  var_names=ndvi                             \
  var_units=ndvi                             \
  var_types=short                            \
  scale_offsets=0                            \
  scale_factors=100                          \
$INPFILE $OUTFILE

exit $status

