#!/bin/csh
# A script to process raw hrpt data from a file
# rather than the passdisk.

set FUNC = $0

# Make sure the user gave an input and output file
# name, and set those arguments to variables.
if ( $#argv != 2 ) then
  echo "Usage: $FUNC <input filename> <output filename>."
  exit 1
else
  set INFILE = $argv[1]
  set OUTFILE = $argv[2]
endif

# Now we're ready to run hrptin on the data.
# Most of the options are left as defaults.
hrptin \
    hrpt_types= \
    on_pass_disk="no" \
    tape_device="$INFILE" \
    pass_year= \
    channels= \
    fix_missing= \
    sharpen= \
    calibrate= \
    temp_units= \
    byte_output= \
    full_report= \
    solar_corr= \
    geo_correct= \
    delta_line= \
    delta_sample= \
    use_master=no \
    start_time= \
    num_lines= \
    start_sample= \
    num_samples= \
    $OUTFILE

# Finally, report whether the processing was
# a success or not.
if ( $status != 0 ) then
  echo "$FUNC - Failed at `date`."
  exit 1
else
  echo "$FUNC - Finished at `date`."
endif

exit 0

