#!/bin/csh
# Processes avhrr data and stores it in a central
# data directory.

set FUNC = $0

# Make sure the user gave a pass number. If so,
# set a variable with that argument.
if ( $#argv != 1 ) then
  echo "Usage: $FUNC <pass number>."
  exit 1
else
  set LASTPASS = $argv[1]
endif

# This is an hrpt only script. If the specified
# pass isn't hrpt, exit with an error.
set TELEM = `passinfo pass_number=$LASTPASS item=telemetry`
if ( "$TELEM" != "hrpt" ) then
  echo "$FUNC - This script requires hrpt data only."
  exit 1
endif

# Use 'passinfo' to find out some information
# about the pass we want to process. Use sed
# to remove characters we don't want.
set SATEL = `passinfo pass_number=$LASTPASS item=satellite`
set DATE = `passinfo pass_number=$LASTPASS item=date | sed 's:/::g'`
set TIME = `passinfo pass_number=$LASTPASS item=time | sed 's/://g'`

# Create our unique filename using the
# information we've gathered.
set OUTFILE = "$SATEL.$DATE.$TIME"

# Set a variable name for the output directory.
# Create the directory if it doesn't exist.
set OUTDIR = "$DATADIR/whole_pass/avhrr"
if ( ! -d $OUTDIR ) then
  mkdir -p $OUTDIR
endif

# Set a variable name for the temporary
# directory and create it.
set TEMPDIR = "$PGSWORKDIR/`date +%y%j.%k%m%S.`$TELEM"
if ( ! -d $TEMPDIR ) then
  mkdir -p $TEMPDIR
endif

# Now we're ready to run hrptin on the data.
# Most of the options are left as defaults.
hrptin \
    hrpt_types="avhrr" \
    on_pass_disk="yes" \
    pass_number=$LASTPASS \
    channels= \
    fix_missing= \
    sharpen= \
    calibrate= \
    temp_units= \
    byte_output= \
    full_report= \
    solar_corr= \
    geo_correct= \
    delta_line= \
    delta_sample= \
    use_master=no \
    start_time= \
    num_lines= \
    start_sample= \
    num_samples= \
    $TEMPDIR/$OUTFILE

# Report whether the processing was a success or not.
if ( $status != 0 ) then
  echo "$FUNC - hrptin failed at `date`."
  exit 1
endif

# Register our data to the San Diego master.
fastreg \
  master_file="/opt/terascan/pass/masters/SanDiego" \
  poly_size= \
  $TEMPDIR/$OUTFILE.avhrr $OUTDIR/$OUTFILE.sandiego

# Report whether the processing was a success or not.
if ( $status != 0 ) then
  echo "$FUNC - fastreg failed at `date`."
  exit 1
endif

# Everything has worked, so remove the temp dirs.
rm -rf $TEMPDIR
echo "$FUNC - Finished at `date`."

exit 0

