#! /bin/csh -f
#  $Id: submit_archive.sh,v 1.7 2004/06/02 14:54:35 jhf Exp $
#  Submit file to archive
#  Creates corresponding thumbnail to store next to file

# Currently only supports TerraSoar
# ---------------------------------

set TERRASOAR = 1

set FUNC = `basename $0`
onintr gotsig

echo ""
echo ${FUNC}: Started at `date`

source $TSCANROOT/bin/logrundefs
set noglob

# Check command line arguments
# ----------------------------

if ($#argv != 6) then
  echo "Usage: $FUNC table-name relative-path input-file"
  echo "             image-var product-name work-dir"
  goto failed
endif

set TABLE    = $1
set RELPATH  = $2
set INPFILE  = $3
set IMAGEVAR = "$4"
set PRODUCT  = "$5"
set WORKDIR  = $6

# Change to work directory
# ------------------------

cd $WORKDIR
if ($status != 0) then
  shout ""
  shout ${FUNC}: Cannot change to work directory $WORKDIR
  goto failed
endif

set TEXTFILE = Text
set DATASET  = Dataset
\rm -f $DATASET $TEXTFILE

# Check for configuration file
# ----------------------------

set CONFIG = $PASSDIR/config/terrasoar.config
if (! -f $CONFIG) then
  shout ""
  shout ${FUNC}: Missing configuration file $CONFIG
  goto failed
endif

# Check for absolute path
# -----------------------

if ($RELPATH =~ /*) then
  set ABSOLUTE = 1
  set ROOTPATH = $RELPATH
  set FULLPATH = $RELPATH
else
  set ABSOLUTE = 0
  logset ROOTPATH getconfig file=$CONFIG family=$TABLE setting=root_path required=yes
  if ($status != 0) goto failed
  set FULLPATH = $ROOTPATH/$RELPATH
endif

# Create directory if it does not already exist
# ---------------------------------------------

if      ($FULLPATH =~ /usr/*) then
else if ($FULLPATH =~ /bin/*) then
else if ($FULLPATH =~ /lib/*) then
else if ($FULLPATH =~ /etc/*) then
else if ($FULLPATH =~ /opt/*) then
else if ($FULLPATH =~ /dev/*) then
else if ($FULLPATH =~ /var/*) then
else if ($FULLPATH =~ /boot/*) then
else if ($FULLPATH =~ /sbin/*) then
else
  logrun - mkdir -p $FULLPATH
endif

if (! -d $FULLPATH) then
  shout ""
  shout ${FUNC}: Cannot create database directory $FULLPATH
  goto failed
endif

# Get database login
# ------------------

logset DBUSER getconfig file=$CONFIG family=mysql setting=user required=yes
if ($status != 0) goto failed

set DBPASSWORD = `getconfig file=$CONFIG family=mysql setting=password required=yes`
if ($status != 0) goto failed

logset DBHOST getconfig file=$CONFIG family=mysql setting=host default=""
if ($status != 0) goto failed

if ($#DBHOST == 1) then
  set HOSTARGS = ( -h $DBHOST )
else
  set HOSTARGS = ()
endif

# Generate quicklook image
# ------------------------

set FILENAME = $INPFILE:t
set SMALLTHUMBNAIL = $FILENAME.small.jpg
set BIGTHUMBNAIL = $FILENAME.big.jpg

logrun quick quicklook variable="$IMAGEVAR" max_width=1024 $INPFILE $BIGTHUMBNAIL
if ($status != 0) goto failed

logrun - convert -scale 320x406 $BIGTHUMBNAIL $SMALLTHUMBNAIL
if ($status != 0) goto failed

# Run logtext here rather than in quicklook
# Must handle both TDF and EOS HDF
# -----------------------------------------

if ($INPFILE:e == hdf) then
    if ($?LASTPASS) then
      logset SATELLITE passinfo item=satellite pass_number=$LASTPASS
      if ($status != 0) goto failed
    else
      set SATELLITE = terra-1
      if ($FILENAME =~ MYD*) set SATELLITE = aqua-1
    endif

    logrun - link_hdf_eos satellite=$SATELLITE create=yes $INPFILE $DATASET
    if ($status != 0) goto failed
    set FORMAT = HDF
else
    ln -s $INPFILE $DATASET
    if ($status != 0) goto failed
    set FORMAT = TDF
endif

# Get satellite, telemetry, sensor required by logtext
# ----------------------------------------------------

logset SATELLITE getinfo attr_name=satellite $DATASET
if ($status != 0) goto failed
logset SENSOR getinfo attr_name=sensor_name $DATASET
if ($status != 0) goto failed

set TELEMETRY = `gettelem $DATASET`
if ($status != 0) set TELEMETRY = unknown

# Generate the TEXT catalog file for TerraSoar
# --------------------------------------------

if ($ABSOLUTE) then
   set RXFILENAME = $FULLPATH/$FILENAME
   set RXBIGTHUMBNAIL = $FULLPATH/$BIGTHUMBNAIL
   set RXSMALLTHUMBNAIL = $FULLPATH/$SMALLTHUMBNAIL
else
   set RXFILENAME = $FILENAME
   set RXBIGTHUMBNAIL = $BIGTHUMBNAIL
   set RXSMALLTHUMBNAIL = $SMALLTHUMBNAIL
endif

echo ""
echo ${FUNC}: Running logtext ...

logtext				\
	var_name=$IMAGEVAR	\
	min_day_sun=5		\
	product="$PRODUCT"	\
	format=$FORMAT		\
	telemetry=$TELEMETRY	\
	sensors=$SENSOR		\
	channels=all		\
	passfilename=$RXFILENAME		\
	smallthumbnail=$RXSMALLTHUMBNAIL	\
	bigthumbnail=$RXBIGTHUMBNAIL		\
	relativepath=$RELPATH	\
    $DATASET >! $TEXTFILE
if ($status != 0) goto failed

# Move file and thumbnail
# -----------------------

if ($TERRASOAR) then
   logrun - cp $INPFILE $FULLPATH
   if ($status != 0) goto failed
   logrun - cp $BIGTHUMBNAIL $FULLPATH
   if ($status != 0) goto failed
   logrun - cp $SMALLTHUMBNAIL $FULLPATH
   if ($status != 0) goto failed
endif

# Ingest into MySQL for TerraSoar
# -------------------------------

if ($TERRASOAR) then

   set TMPDIR = $DATADIR/tmp
   logrun - mkdir -p $TMPDIR
   if ($status != 0) goto failed

   set UNIQ = `hostname`.$$

   set DBOUT = $TMPDIR/$UNIQ
   \rm -f $DBOUT $DBOUT.sql

   logrun - tsoardb $TEXTFILE $DBOUT $TABLE
   if ($status != 0) then
     \rm -f $DBOUT $DBOUT.sql
     goto failed
   endif

   echo ""
   echo "mysql $HOSTARGS -u $DBUSER -p<password> < $DBOUT.sql"
   echo ""

   mysql $HOSTARGS -u $DBUSER -p$DBPASSWORD < $DBOUT.sql
   set STATUS = $status

   \rm -f $DBOUT $DBOUT.sql

   if ($STATUS != 0) goto failed
endif

# Termination section
# -------------------
set STATUS = 0
goto done

gotsig:

shout ""
shout ${FUNC}: Failed - Received interrupt signal

failed:

set STATUS = 1

done:

echo ""
echo ${FUNC}: Ended at `date`
echo ${FUNC}: Exiting with error status $STATUS

exit $STATUS

